@@ -226,19 +226,28 @@ class MediaLibrary():
             if terms:
                 for song in self.__songs:
                     missingTerm = False
+
                     if song.blIsVideo and not searchVideo:
                         continue
                     elif not song.blIsVideo and not searchAudio:
                         continue
-                    for term in terms:
-                        term = term.encode('UTF-8', 'replace').lower()
-                        title = song.title.lower()
-                        artist = song.artist.lower()
-                        if (term not in title) and (term not in artist):
-                            missingTerm = True
-                            break
-                    if not missingTerm:
-                        songsFound.append(song)
-            return songsFound
+                    else:
+                        for term in terms:
+                            term = term.encode('UTF-8', 'replace').lower()
+                            title = song.title.lower()
+                            artist = song.artist.lower()
+                            if (term not in title) and (term not in artist):
+                                missingTerm = True
+                                break
+
+                        if not missingTerm:
+                            songsFound.append(song)
         else:
-            return self.__songs
+            for song in self.__songs:
+                if song.blIsVideo and not searchVideo:
+                    continue
+                elif not song.blIsVideo and not searchAudio:
+                    continue
+                else:
+                    songsFound.append(song)
+        return songsFound
