@@ -50,6 +50,8 @@ class PlayerWindow(wx.Panel):
     ID_TRACK_POSITION = wx.NewId()
     # Used to indicate to change the volume level.
     ID_VOLUME = wx.NewId()
+    # Used to Mute/UnMute the volume
+    ID_MUTE = wx.NewId()
 
     def __init__(self, parent, id=wx.NewId(), volume=50):
         """ Default constructor
@@ -60,6 +62,7 @@ class PlayerWindow(wx.Panel):
         """
         wx.Panel.__init__(self, parent, id)
         self.__createControls(volume)
+        self.__bindEvents()
         self.__doLayout()
 
     def __createControls(self, volume):
@@ -78,6 +81,8 @@ class PlayerWindow(wx.Panel):
         self.__sldrTrackPosition = wx.Slider(self, self.ID_TRACK_POSITION, \
             0, self.__TRACK_MINIMUM, self.__TRACK_MAXIMUM, \
             style=wx.SL_AUTOTICKS)
+        self.__sttcTxtSongProgress = wx.StaticText(self, wx.ID_ANY, \
+            "Song Progress")
 
         # Create Player Buttons
         self.__bttnPlay = wx.Button(self, self.ID_PLAY, "Play")
@@ -87,55 +92,60 @@ class PlayerWindow(wx.Panel):
         self.__bttnStop.Enable(False)
 
         # Volume Control
+        self.__sttcTxtSongVolume = wx.StaticText(self, wx.ID_ANY, \
+            "Volume")
         self.__sldrVolume = wx.Slider(self, self.ID_VOLUME, volume, \
             self.__VOLUME_MINIMUM, self.__VOLUME_MAXIMUM, \
-            style=wx.SL_VERTICAL | wx.SL_INVERSE | wx.SL_RIGHT | wx.SL_LABELS)
+            style=wx.SL_RIGHT | wx.SL_LABELS)
+        self.__bttnMute = wx.Button(self, self.ID_MUTE, "Mute")
+        self.__bttnMute.Enable(False)
 
+    def __bindEvents(self):
+        """ Connects all the needed events.
+
+         Connects each of the control objects created to their corresponding
+           methods.
+        """
+        pass
 
     def __doLayout(self):
         """ Places the controls in a defined layout. """
 
-        # Track Time Layout
-        self.__bxSzrTimePosition = wx.BoxSizer(wx.HORIZONTAL)
-        self.__bxSzrTimePosition.Add(self.__sttcTxtTimePosition, 0, \
-            wx.ALL | wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTimePosition.Add(self.__txtCtrlTimePosition, 0, \
-            wx.ALL | wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTimeTotal = wx.BoxSizer(wx.HORIZONTAL)
-        self.__bxSzrTimeTotal.Add(self.__sttcTxtTimeTotal, 0, wx.ALL | \
-            wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTimeTotal.Add(self.__txtCtrlTimeTotal, 0, wx.ALL | \
-            wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTrackTime = wx.BoxSizer(wx.VERTICAL)
-        self.__bxSzrTrackTime.Add(self.__bxSzrTimePosition, 0, wx.ALL | \
-            wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTrackTime.Add(self.__bxSzrTimeTotal, 0, wx.ALL | \
-            wx.ALIGN_RIGHT, 3)
-        self.__bxSzrTrackTime.AddSpacer(5)
-        self.__bxSzrTrackTime.Add(self.__sldrTrackPosition, 1, wx.EXPAND | \
-            wx.ALIGN_RIGHT)
-
         # Player Layout
-        self.__bxSzrPlayerControlsRow0 = wx.BoxSizer(wx.HORIZONTAL)
+        self.__bxSzrPlayerControlsRow0 = wx.GridSizer(1, 4)
+        self.__bxSzrPlayerControlsRow0.Add(self.__sttcTxtTimePosition, 0, \
+            wx.ALL | wx.ALIGN_RIGHT, 3)
+        self.__bxSzrPlayerControlsRow0.Add(self.__txtCtrlTimePosition, 0, \
+            wx.ALL | wx.ALIGN_RIGHT, 3)
         self.__bxSzrPlayerControlsRow0.Add(self.__bttnPlay, 0, wx.ALL, 3)
         self.__bxSzrPlayerControlsRow0.Add(self.__bttnRestart, 0, wx.ALL, 3)
-        self.__bxSzrPlayerControlsRow1 = wx.BoxSizer(wx.HORIZONTAL)
+
+
+        self.__bxSzrPlayerControlsRow1 = wx.GridSizer(1, 4)
+        self.__bxSzrPlayerControlsRow1.Add(self.__sttcTxtTimeTotal, 0, \
+            wx.ALL | wx.ALIGN_RIGHT, 3)
+        self.__bxSzrPlayerControlsRow1.Add(self.__txtCtrlTimeTotal, 0, \
+            wx.ALL | wx.ALIGN_RIGHT, 3)
         self.__bxSzrPlayerControlsRow1.Add(self.__bttnStop, 0, wx.ALL, 3)
+
         self.__bxSzrPlayerControls = wx.BoxSizer(wx.VERTICAL)
         self.__bxSzrPlayerControls.AddSizer(self.__bxSzrPlayerControlsRow0, \
             0, wx.ALL, 3)
         self.__bxSzrPlayerControls.AddSizer(self.__bxSzrPlayerControlsRow1, \
             0, wx.ALL, 3)
+        self.__bxSzrPlayerControls.Add(self.__sttcTxtSongProgress, 0)
+        self.__bxSzrPlayerControls.Add(self.__sldrTrackPosition, 1, wx.EXPAND)
 
         # Volume Layout
-        self.__bxSzrVolume = wx.BoxSizer(wx.HORIZONTAL)
-        self.__bxSzrVolume.Add(self.__sldrVolume, 1, wx.EXPAND)
+        self.__bxSzrVolume = wx.BoxSizer(wx.VERTICAL)
+        self.__bxSzrVolume.Add(self.__sttcTxtSongVolume, 0, wx.ALIGN_CENTER)
+        self.__bxSzrVolume.Add(self.__sldrVolume, 0, wx.EXPAND)
+        self.__bxSzrVolume.AddStretchSpacer()
+        self.__bxSzrVolume.Add(self.__bttnMute, 0)
 
         # Create Interface
         self.__bxSzrInterface = wx.BoxSizer(wx.HORIZONTAL)
-        self.__bxSzrInterface.AddStretchSpacer(4)
-        self.__bxSzrInterface.Add(self.__bxSzrTrackTime, 0, wx.EXPAND)
-        self.__bxSzrInterface.AddSpacer(5)
+        self.__bxSzrInterface.AddStretchSpacer()
         self.__bxSzrInterface.Add(self.__bxSzrPlayerControls, 0, wx.EXPAND)
         self.__bxSzrInterface.Add(self.__bxSzrVolume, 1, wx.EXPAND | \
             wx.FIXED_MINSIZE)
@@ -150,6 +160,16 @@ class PlayerWindow(wx.Panel):
         """ Modifier to the displayed volume level. """
         self.__sldrVolume.SetValue(volume)
 
+    def toggleMute(self):
+        """ Toggles the volume between mute and un-mute. """
+        if self.volumeLevel() == 0:
+            self.setVolumeLevel(self.__preMuteVolume)
+            self.__bttnMute.SetLabel("Mute")
+        else:
+            self.__preMuteVolume = self.volumeLevel()
+            self.setVolumeLevel(0)
+            self.__bttnMute.SetLabel("Unmute")
+
     def trackPosition(self):
         """ Accessor to the displayed track position. """
         return self.__sldrTrackPosition.GetValue()
@@ -196,5 +216,7 @@ class PlayerWindow(wx.Panel):
         """
         if self.__bttnPlay.GetLabel() == "Play":
             self.__bttnPlay.SetLabel("Pause")
+            self.__bttnMute.Enable(True)
         else:
             self.__bttnPlay.SetLabel("Play")
+            self.__bttnMute.Enable(False)
